#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# six_story_burbank.tcl :six story, MRF-6 bay
#
# Writen by:  Erol Kalkan
# Last modified:  Sept 2003
#
# Objective: 2D modeling panel zone effects taken into account, Eigen analysis 
#
# Units: kip-in      
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#====================================================================
# Destroy all constructed objects
wipe;

#====================================================================
# DEFINE ANALYSIS CASE

set AnalysisOption "Static";             # Pushover Analysis
#set AnalysisOption "Dynamic";            # Time History Analysis
#set AnalysisOption "Eigen";             # Pushover Analysis

#====================================================================
# DEFINE THE MODEL BUILDER
model BasicBuilder -ndm 2 -ndf 3;

#====================================================================
# DEFINE NODAL COORDINATES 
source nodes.tcl

#====================================================================
# DEFINE MATERIALS
source mat.tcl

#====================================================================
# DEFINE SECTIONS
source xsection.tcl

#====================================================================
# COLUMN AND BEAM ASSIGNMENT  
source assign.tcl

#====================================================================

puts "ANALYSIS START !!!"

if {$AnalysisOption == "Eigen"} {
	source eigen.tcl
}
if {$AnalysisOption == "Static"} {
      source gravity.tcl
	source gravityanalysis.tcl

set NSP 100; # Loading pattern for pushover analysis
	source pushover.tcl
	source pushoveranalysis.tcl
}
if {$AnalysisOption == "Dynamic"} {
      source gravity.tcl
	source gravityanalysis.tcl
	source dynamic.tcl
}

wipe

#====================================================================
#                                DONE !!!!
#====================================================================

